@@ -1,9 +1,16 @@
-/* uspk12.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -21,9 +28,9 @@ static integer c__51 = 51;
 static integer c__21 = 21;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* System generated locals */
     doublereal d__1;
@@ -36,15 +43,14 @@ static integer c__21 = 21;
 
     /* Local variables */
     static integer i__, j;
-    static real t, u[1071]	/* was [51][21] */, z__;
-    extern /* Subroutine */ int grcls_(void), grfrm_(void), gropn_(integer *);
-    static real uz;
-    extern /* Subroutine */ int udcntr_(real *, integer *, integer *, integer 
-	    *), grswnd_(real *, real *, real *, real *), grstrf_(void), 
-	    usdaxs_(void), grstrn_(integer *), sgpwsn_(void), grsvpt_(real *, 
-	    real *, real *, real *), ussttl_(char *, char *, char *, char *, 
-	    ftnlen, ftnlen, ftnlen, ftnlen);
+    static real t, u[1071]	/* was [51][21] */, z__, uz;
     static integer iws;
+    extern /* Subroutine */ int grcls_(void), grfrm_(void), gropn_(integer *),
+	     udcntr_(real *, integer *, integer *, integer *), grswnd_(real *,
+	     real *, real *, real *), grstrf_(void), usdaxs_(void), grstrn_(
+	    integer *), sgpwsn_(void), grsvpt_(real *, real *, real *, real *)
+	    , ussttl_(char *, char *, char *, char *, ftnlen, ftnlen, ftnlen, 
+	    ftnlen);
 
     /* Fortran I/O blocks */
     static cilist io___7 = { 0, 6, 0, 0, 0 };
