@@ -1,5 +1,5 @@
 /* Copyright (C) by GFD-Dennou Club, 1999-2000.  All rights reserved. */
-#include "f2c.h"
+#include "libtinyf2c.h"
 #include "fio.h"
 
 /* rewind the file.
