@@ -1,9 +1,16 @@
-/* repsl.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -13,9 +20,9 @@ static integer c__1 = 1;
 /* ----------------------------------------------------------------------- */
 /*     PRESISION OF REAL VARIABLE                             (94/09/17) */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* System generated locals */
     real r__1;
@@ -26,16 +33,12 @@ static integer c__1 = 1;
     /* Subroutine */ int s_stop(char *, ftnlen);
 
     /* Local variables */
-    static real emin, emax;
-    static integer i__;
-    static real delta;
-    extern /* Subroutine */ int sbyte_(real *, integer *, integer *, integer *
-	    );
-    static integer i0, i1;
-    static real s0, s1, pi, th;
-    extern /* Subroutine */ int gliget_(char *, integer *, ftnlen);
-    static real eps;
+    static integer i__, i0, i1;
+    static real s0, s1, pi, th, eps;
     static integer iou;
+    static real emin, emax, delta;
+    extern /* Subroutine */ int sbyte_(real *, integer *, integer *, integer *
+	    ), gliget_(char *, integer *, ftnlen);
 
     /* Fortran I/O blocks */
     static cilist io___13 = { 0, 0, 0, "(A,1P,E10.3)", 0 };
@@ -53,9 +56,9 @@ static integer c__1 = 1;
 	sbyte_(&s0, &i0, &c__31, &c__1);
 	sbyte_(&s1, &i1, &c__31, &c__1);
 	delta = s1 - s0;
-	eps = (r__1 = delta / s1, dabs(r__1));
-	emax = dmax(eps,emax);
-	emin = dmin(eps,emin);
+	eps = (r__1 = delta / s1, abs(r__1));
+	emax = max(eps,emax);
+	emin = min(eps,emin);
 /* L100: */
     }
     gliget_("IOUNIT", &iou, (ftnlen)6);
