@@ -52,7 +52,7 @@ static integer c__0 = 0;
     static char cmap[80];
     extern integer lenc_(char *, ftnlen);
     static char cmsg[80];
-    static logical lalt, lkey, lwnd;
+    static logical lalt, lsep, lkey, lwnd;
     static char cttl[80], cout[80];
     static logical lfgbg;
     extern /* Subroutine */ int chngi_(char *, char *, integer *, char *, 
@@ -76,11 +76,12 @@ static integer c__0 = 0;
 	    *, ftnlen, ftnlen), zgdcls_(void), swqcmf_(integer *, char *, 
 	    ftnlen), swcmll_(void), swiget_(char *, integer *, ftnlen), 
 	    zgdopn_(integer *, integer *, integer *, integer *, integer *, 
-	    integer *, logical *, logical *, logical *, logical *, integer *, 
-	    logical *, logical *, logical *, logical *, integer *, char *, 
-	    real *, char *, char *, char *, char *, ftnlen, ftnlen, ftnlen, 
-	    ftnlen, ftnlen), swlget_(), zgpcls_(void), swcset_(char *, char *,
-	     ftnlen, ftnlen), swqfnm_(char *, char *, ftnlen, ftnlen);
+	    integer *, integer *, logical *, logical *, logical *, logical *, 
+	    integer *, logical *, logical *, logical *, logical *, logical *, 
+	    integer *, char *, real *, char *, char *, char *, char *, ftnlen,
+	     ftnlen, ftnlen, ftnlen, ftnlen), swlget_(), zgpcls_(void), 
+	    swcset_(char *, char *, ftnlen, ftnlen), swqfnm_(char *, char *, 
+	    ftnlen, ftnlen);
     static integer lstdot;
     extern /* Subroutine */ int swrget_(char *, real *, ftnlen), zgpopn_(void)
 	    , zgoopn_(char *, char *, ftnlen, ftnlen), zgocls_(char *, ftnlen)
@@ -92,7 +93,9 @@ static integer c__0 = 0;
 	    zgiclr_(integer *, integer *), zgicls_(void), zgqpnt_(real *, 
 	    real *, integer *), zgfint_(real *, real *, integer *, integer *),
 	     zgiint_(integer *, integer *, real *, real *), zgqwdc_(logical *)
-	    , zgqclc_(logical *), zgqtnc_(logical *), zgqimc_(logical *), 
+	    , zgqclc_(logical *);
+    static integer ibgpage;
+    extern /* Subroutine */ int zgqtnc_(logical *), zgqimc_(logical *), 
 	    zgqptc_(logical *), zgqrct_(real *, real *, real *, real *, real *
 	    ), zgsrot_(integer *);
     static char cimgfmt[8];
@@ -162,6 +165,7 @@ static integer c__0 = 0;
 	swcget_("FNAME  ", cout, (ftnlen)7, (ftnlen)80);
 	swcget_("TITLE  ", cttl, (ftnlen)7, (ftnlen)80);
 	swiget_("IDMPDGT ", &idmpdgt, (ftnlen)8);
+	swiget_("IBGPAGE ", &ibgpage, (ftnlen)8);
 	swcmll_();
 	swqfnm_("CLRMAP ", clrmap, (ftnlen)7, (ftnlen)80);
 	glcget_("DSPATH", dspath, (ftnlen)6, (ftnlen)80);
@@ -209,12 +213,12 @@ static integer c__0 = 0;
     swlget_("LWND   ", &lwnd, (ftnlen)7);
     swcget_("CIMGFMT ", cimgfmt, (ftnlen)8, (ftnlen)8);
     swrget_("RIMGCMP ", &rimgcmp, (ftnlen)8);
-    zgdopn_(&iws, &iwidth, &iheigh, &iposx, &iposy, &idmpdgt, &lwait, &lwait0,
-	     &lwait1, &lalt, &lstdot, &lkey, &ldump, &lwnd, &lfgbg, &ifl, 
-	    cimgfmt, &rimgcmp, clrmap, cbtmap, cout, cttl, (ftnlen)8, (ftnlen)
-	    80, (ftnlen)80, (ftnlen)80, (ftnlen)80);
+    swlget_("LSEP   ", &lsep, (ftnlen)7);
+    zgdopn_(&iws, &iwidth, &iheigh, &iposx, &iposy, &idmpdgt, &ibgpage, &
+	    lwait, &lwait0, &lwait1, &lalt, &lstdot, &lkey, &ldump, &lwnd, &
+	    lfgbg, &lsep, &ifl, cimgfmt, &rimgcmp, clrmap, cbtmap, cout, cttl,
+	     (ftnlen)8, (ftnlen)80, (ftnlen)80, (ftnlen)80, (ftnlen)80);
 /*        CALL SWLGET('LCOLOR ', LCOLOR) */
-/*        CALL SWLGET('LSEP   ', LSEP  ) */
 /*        CALL SWLGET('LPRINT ', LPRINT) */
 /*        CALL SWCGET('LPR    ', CLPR  ) */
     lopen = TRUE_;
