@@ -1,22 +1,30 @@
-/* ulxlog.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
+static real c_b13 = 1.f;
 static logical c_true = TRUE_;
 static integer c__10 = 10;
 static integer c__1 = 1;
-static real c_b27 = 10.f;
+static real c_b28 = 10.f;
 static integer c__4 = 4;
 static integer c__2 = 2;
 static integer c__16 = 16;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int ulxlog_(char *cside, integer *nlbl, integer *nticks, 
 	ftnlen cside_len)
@@ -24,17 +32,29 @@ static integer c__16 = 16;
     /* System generated locals */
     address a__1[4], a__2[2];
     integer i__1, i__2, i__3, i__4[4], i__5[2];
+    real r__1, r__2;
     char ch__1[1], ch__2[1], ch__3[7];
     icilist ici__1;
 
     /* Builtin functions */
-    double pow_ri(real *, integer *);
+    double r_sign(real *, real *), pow_ri(real *, integer *);
     integer s_wsfi(icilist *), do_fio(integer *, char *, ftnlen), e_wsfi(void)
 	    ;
     /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen), s_cat(char *,
 	     char **, integer *, integer *, ftnlen);
 
     /* Local variables */
+    static char ch[16*50];
+    static integer ib;
+    static real bl[10];
+    static integer nb;
+    static real bs[10];
+    static integer ip;
+    static real ux1[200], ux2[50];
+    static integer nbl;
+    static char chr[8], chw[16];
+    static integer nbs, nbt;
+    static real sgn, uxt[50], xxx;
     extern /* Subroutine */ int gnge_(real *, real *, integer *);
     extern /* Character */ VOID csgi_(char *, ftnlen, integer *);
     static logical loff;
@@ -57,14 +77,7 @@ static integer c__16 = 16;
     static integer ipmin, itype;
     extern /* Subroutine */ int vrgnn_(real *, integer *, integer *);
     static integer jtype;
-    static real uxmin, uymin, uxmax, uymax;
-    static char ch[16*50];
-    static integer ib;
-    static real bl[10];
-    static integer nb;
-    static real bs[10];
-    static integer ip;
-    static real factor;
+    static real uxmin, uymin, uxmax, uymax, factor;
     extern /* Subroutine */ int gllget_(char *, logical *, ftnlen), gnsblk_(
 	    real *, integer *), sgiget_(char *, integer *, ftnlen), gnsave_(
 	    void), sglget_(char *, logical *, ftnlen), msgdmp_(char *, char *,
@@ -79,14 +92,9 @@ static integer c__16 = 16;
 	    logical *, ftnlen), uzrget_(char *, real *, ftnlen), uxpaxs_(char 
 	    *, integer *, ftnlen), uxptmk_(char *, integer *, real *, integer 
 	    *, ftnlen);
-    static real ux1[200], ux2[50];
-    static integer nbl;
-    static char chr[8];
-    static integer nbs, nbt;
-    static real uxt[50], xxx;
 
     /* Fortran I/O blocks */
-    static icilist io___34 = { 0, chr, 0, "(I8)", 8, 1 };
+    static icilist io___35 = { 0, chr, 0, "(I8)", 8, 1 };
 
 
 /*     CSIDE : 'T','B','U' */
@@ -116,7 +124,8 @@ static integer c__16 = 16;
 	xmin = uxmin;
 	xmax = uxmax;
     }
-    if (xmin > xmax) {
+    sgn = r_sign(&c_b13, &xmin);
+    if (sgn * xmin > sgn * xmax) {
 	xxx = xmin;
 	xmin = xmax;
 	xmax = xxx;
@@ -135,8 +144,10 @@ static integer c__16 = 16;
     bs[*nticks] = 10.f;
     i__1 = *nticks + 1;
     gnsblk_(bs, &i__1);
-    gnle_(&xmax, &bxmax, &ipmax);
-    gnge_(&xmin, &bxmin, &ipmin);
+    r__1 = abs(xmax);
+    gnle_(&r__1, &bxmax, &ipmax);
+    r__1 = abs(xmin);
+    gnge_(&r__1, &bxmin, &ipmin);
     nbs = 0;
     i__1 = ipmax;
     for (ip = ipmin; ip <= i__1; ++ip) {
@@ -153,7 +164,7 @@ static integer c__16 = 16;
 		msgdmp_("E", "ULXLOG", "TOO MANY TICKS.", (ftnlen)1, (ftnlen)
 			6, (ftnlen)15);
 	    }
-	    ux1[nbs - 1] = bs[ib - 1] * pow_ri(&c_b27, &ip);
+	    ux1[nbs - 1] = sgn * bs[ib - 1] * pow_ri(&c_b28, &ip);
 L100:
 	    ;
 	}
@@ -161,8 +172,10 @@ L100:
 /*     LARGE LABELS AND TICKS */
     i__2 = nb + 1;
     gnsblk_(bl, &i__2);
-    gnle_(&xmax, &bxmax, &ipmax);
-    gnge_(&xmin, &bxmin, &ipmin);
+    r__1 = abs(xmax);
+    gnle_(&r__1, &bxmax, &ipmax);
+    r__1 = abs(xmin);
+    gnge_(&r__1, &bxmin, &ipmin);
     nbl = 0;
     nbt = 0;
     jtype = itype % 2;
@@ -178,14 +191,14 @@ L100:
 	    }
 	    if (ib == 1) {
 		++nbt;
-		uxt[nbt - 1] = pow_ri(&c_b27, &ip);
+		uxt[nbt - 1] = sgn * pow_ri(&c_b28, &ip);
 	    }
 	    ++nbl;
 	    if (nbl > 50) {
 		msgdmp_("E", "ULXLOG", "TOO MANY LABELS.", (ftnlen)1, (ftnlen)
 			6, (ftnlen)16);
 	    }
-	    ux2[nbl - 1] = bl[ib - 1] * pow_ri(&c_b27, &ip);
+	    ux2[nbl - 1] = sgn * bl[ib - 1] * pow_ri(&c_b28, &ip);
 	    if (itype <= 2) {
 		if (jtype == 0 && ib != 1) {
 		    ici__1.icierr = 0;
@@ -216,7 +229,7 @@ L100:
 			s_copy(ch + (nbl - 1 << 4), " ", (ftnlen)16, (ftnlen)
 				1);
 		    }
-		    s_wsfi(&io___34);
+		    s_wsfi(&io___35);
 		    do_fio(&c__1, (char *)&ip, (ftnlen)sizeof(integer));
 		    e_wsfi();
 		    cladj_(chr, (ftnlen)8);
@@ -252,8 +265,9 @@ L100:
 		    e_wsfi();
 		} else {
 		    uzcget_("CXFMT", cfmt, (ftnlen)5, (ftnlen)16);
-		    chval_(cfmt, &ux2[nbl - 1], ch + (nbl - 1 << 4), (ftnlen)
-			    16, (ftnlen)16);
+		    r__2 = (r__1 = ux2[nbl - 1], abs(r__1));
+		    chval_(cfmt, &r__2, ch + (nbl - 1 << 4), (ftnlen)16, (
+			    ftnlen)16);
 		    cladj_(ch + (nbl - 1 << 4), (ftnlen)16);
 		}
 	    }
@@ -261,6 +275,17 @@ L201:
 	    ;
 	}
     }
+    if (sgn < 0.f) {
+	i__1 = nbl;
+	for (ib = 1; ib <= i__1; ++ib) {
+/* Writing concatenation */
+	    i__5[0] = 1, a__2[0] = "-";
+	    i__5[1] = 16, a__2[1] = ch + (ib - 1 << 4);
+	    s_cat(chw, a__2, i__5, &c__2, (ftnlen)16);
+	    s_copy(ch + (ib - 1 << 4), chw, (ftnlen)16, (ftnlen)16);
+/* L301: */
+	}
+    }
 /*     DRAW AXIS, TICKS, AND LABELS */
     uxpaxs_(cside, &c__2, (ftnlen)1);
     if (nbs != 0) {
