@@ -1,9 +1,16 @@
-/* csblbl.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -15,7 +22,7 @@ static integer c__4 = 4;
 /*     USPACK GET CHARACTER FOR SUBLABEL               S.Sakai  90/02/24 */
 /*                                                              92/02/27 */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Character */ VOID csblbl_(char *ret_val, ftnlen ret_val_len, real *ufac, 
 	real *uoff, char *cunit__, ftnlen cunit_len)
@@ -30,6 +37,7 @@ static integer c__4 = 4;
 	     char **, integer *, integer *, ftnlen);
 
     /* Local variables */
+    static integer nlf, nls;
     extern integer lenc_(char *, ftnlen);
     extern /* Character */ VOID csgi_(char *, ftnlen, integer *);
     static char csub[32];
@@ -39,7 +47,6 @@ static integer c__4 = 4;
     static char choff[16], cblkt[2];
     extern /* Subroutine */ int uscget_(char *, char *, ftnlen, ftnlen), 
 	    uschvl_(real *, char *, ftnlen);
-    static integer nlf, nls;
 
     uscget_("CBLKT", cblkt, (ftnlen)5, (ftnlen)2);
 /* ----------------------- OFFSET AND FACTOR ----------------------------- */
