@@ -1,9 +1,16 @@
-/* uurget.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -12,18 +19,18 @@ static integer c__1 = 1;
 /* ----------------------------------------------------------------------- */
 /*     UURGET / UURSET / UURSTX */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int uurget_0_(int n__, char *cp, real *rpara, ftnlen cp_len)
 {
     static char cl[40], cx[8];
     static real rp;
+    static integer idx;
     extern /* Subroutine */ int rlrget_(char *, real *, integer *, ftnlen), 
 	    rtrget_(char *, char *, real *, integer *, ftnlen, ftnlen), 
 	    uurqid_(char *, integer *, ftnlen), uurqcl_(integer *, char *, 
 	    ftnlen), uurqcp_(integer *, char *, ftnlen), uurqvl_(integer *, 
 	    real *), uursvl_(integer *, real *);
-    static integer idx;
 
     switch(n__) {
 	case 1: goto L_uurset;
