@@ -1,14 +1,21 @@
-/* mpfmwd.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* ----------------------------------------------------------------------- */
 /*     MAP PROJECTION (MOLLWEIDE)                       93/02/20 S.SAKAI */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int mpfmwd_0_(int n__, real *xlon, real *ylat, real *x, real 
 	*y)
@@ -17,13 +24,13 @@
     double cos(doublereal), sin(doublereal), asin(doublereal);
 
     /* Local variables */
-    extern doublereal rfpi_(void);
-    static real alpha, pi;
+    static real pi, rna;
+    extern real rfpi_(void);
+    static real alpha;
     extern /* Subroutine */ int glrget_(char *, real *, ftnlen);
-    extern doublereal xmplon_(real *);
+    extern real xmplon_(real *);
     extern /* Subroutine */ int mpzmwd_();
     extern /* Subroutine */ int mpznwt_(U_fp, real *, real *);
-    static real rna;
 
     switch(n__) {
 	case 1: goto L_mpimwd;
@@ -39,14 +46,14 @@
 
 L_mpimwd:
     pi = rfpi_();
-    if (dabs(*y) < 1.4142136f) {
+    if (abs(*y) < 1.4142136f) {
 	alpha = asin(*y / 1.4142136f);
 	*xlon = *x / 1.4142136f / cos(alpha) * pi / 2;
-	if (dabs(*xlon) <= pi) {
+	if (abs(*xlon) <= pi) {
 	    *ylat = asin((alpha * 2 + sin(alpha * 2)) / pi);
 	    return 0;
 	}
-    } else if (dabs(*y) == 1.4142136f && *x == 0.f) {
+    } else if (abs(*y) == 1.4142136f && *x == 0.f) {
 	*xlon = 0.f;
 	*ylat = *y / 1.4142136f / 2 * pi;
 	return 0;
