@@ -1,16 +1,23 @@
-/* mszdmp.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
 static integer c__1 = 1;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int mszdmp_(char *cmsg, integer *iunit, integer *lnsize, 
 	ftnlen cmsg_len)
@@ -24,9 +31,11 @@ static integer c__1 = 1;
 	    , s_wsfe(cilist *), e_wsfe(void);
 
     /* Local variables */
+    static integer m;
+    static char cfm[12];
     extern integer lenc_(char *, ftnlen);
-    static integer mmsg, nmsg, m;
-    static char cmsgx[200], cfm[12];
+    static integer mmsg, nmsg;
+    static char cmsgx[200];
 
     /* Fortran I/O blocks */
     static icilist io___5 = { 0, cfm+6, 0, "(I3)", 3, 1 };
