@@ -1,14 +1,21 @@
-/* rpnget.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* ----------------------------------------------------------------------- */
 /*     GET EXTERNAL PARAMETERS */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int rpnget_0_(int n__, char *cpfix, char *cps, integer *
 	ipara, integer *max__, logical *lpara, real *rpara, char *cpara, char 
@@ -26,9 +33,9 @@
     integer s_cmp(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
+    static integer n;
     static logical lglc;
     extern integer lenc_(char *, ftnlen);
-    static integer n;
     extern logical lchreq_(char *, char *, ftnlen, ftnlen);
     extern /* Subroutine */ int rlcxfl_(char *, char *, ftnlen, ftnlen), 
 	    rlcenv_(char *, char *, ftnlen, ftnlen), rlixfl_(char *, integer *
