@@ -1,14 +1,22 @@
-/* Copyright (C) by GFD-Dennou Club, 1999-2000.  All rights reserved. */
-/* shlfwl.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* ********************************************************************** */
 /*     FORWARD LEGENDRE TRANSFORMATION (LOWER LEVEL) */
 /* ********************************************************************** */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/* ----------------------------------------------------------------------- */
 /* Subroutine */ int shlfwl_(integer *mm, integer *jm, integer *n, integer *m,
 	 real *wx, real *sd, real *pm)
 {
@@ -24,7 +32,7 @@
     pm_offset = 0 + pm_dim1 * 0;
     pm -= pm_offset;
     wx_dim1 = *jm - 0 + 1;
-    wx_offset = 0 + wx_dim1 * 1;
+    wx_offset = 0 + wx_dim1;
     wx -= wx_offset;
 
     /* Function Body */
